==> pd.drosgenome1_1.6.0.tar.gz: pd.drosgenome1/R/all.R <==
globals <- new.env(hash=TRUE, parent=emptyenv())

globals$DEBUG <- FALSE

## setup the path at package level so that DB can be accessed
## during package install/lazyload db creation.
##
## We reset the DB_PATH in .onLoad since we need to
## get the right one based on libpath
globals$DB_PATH <- system.file("extdata", "pd.drosgenome1.sqlite",
                               package="pd.drosgenome1")
if (nchar(globals$DB_PATH) == 0)
  stop("Unable to locate DB file")

initDbConnection <- function() {
    globals$dbCon <- dbConnect(dbDriver("SQLite"), dbname=globals$DB_PATH)
    globals$dbCon
}

getDb  <- function() {
    if (!is.null(globals$dbCon) && isIdCurrent(globals$dbCon))
      return(globals$dbCon)
    initDbConnection()
}

closeDb <- function() {
    ## FIXME: check for valid connection?
    sapply(dbListResults(globals$dbCon), dbClearResult)
    dbDisconnect(globals$dbCon)
    remove(list="dbCon", envir=globals)
}

.onLoad <- function(libname, pkgname) {
    require(RSQLite, quietly=TRUE)
    globals$DB_PATH <- system.file("extdata", "pd.drosgenome1.sqlite",
                                   package="pd.drosgenome1",
                                   lib.loc=libname)
    if (nchar(globals$DB_PATH) == 0)
      stop("Unable to locate DB file")
    ## Establish a connection to the SQLite DB
    initDbConnection()
}

.onUnload <- function(libpath) {
    closeDb()
}

pd.drosgenome1 <- new("AffyExpressionPDInfo",
                    genomebuild="",
                    getdb=getDb,
                    geometry=as.integer(strsplit("640;640", ";")[[1]]),
                    annotation="pd.drosgenome1")

==> pd.drosgenome1_1.8.0.tar.gz: pd.drosgenome1/R/all.R <==
globals <- new.env(hash=TRUE, parent=emptyenv())

globals$DEBUG <- FALSE

## setup the path at package level so that DB can be accessed
## during package install/lazyload db creation.
##
## We reset the DB_PATH in .onLoad since we need to
## get the right one based on libpath
globals$DB_PATH <- system.file("extdata", "pd.drosgenome1.sqlite",
                               package="pd.drosgenome1")
if (nchar(globals$DB_PATH) == 0)
  stop("Unable to locate DB file")

initDbConnection <- function() {
    globals$dbCon <- dbConnect(dbDriver("SQLite"), dbname=globals$DB_PATH)
    globals$dbCon
}

getDb  <- function() {
    if (!is.null(globals$dbCon) && isIdCurrent(globals$dbCon))
      return(globals$dbCon)
    initDbConnection()
}

closeDb <- function() {
    ## FIXME: check for valid connection?
    if (isIdCurrent(globals$dbCon)){
        sapply(dbListResults(globals$dbCon), dbClearResult)
        dbDisconnect(globals$dbCon)
    }
    remove(list="dbCon", envir=globals)
}

.onAttach <- function(libname, pkgname) {
    globals$DB_PATH <- system.file("extdata", "pd.drosgenome1.sqlite",
                                   package="pd.drosgenome1",
                                   lib.loc=libname)
    if (nchar(globals$DB_PATH) == 0)
      stop("Unable to locate DB file")
    ## Establish a connection to the SQLite DB
    initDbConnection()
}

.onUnload <- function(libpath) {
    closeDb()
}

pd.drosgenome1 <- new("AffyExpressionPDInfo",
                    genomebuild="",
                    getdb=getDb,
                    geometry=as.integer(strsplit("640;640", ";")[[1]]),
                    annotation="pd.drosgenome1")
